Welcome to heamy's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   usage
   installation
   contributing

API
===

.. toctree::
   :maxdepth: 2

   dataset
   estimator
   pipeline
   feature

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

